@@ -3,8 +3,8 @@ use std::error::Error;
 use std::fs;
 use std::path::Path;
 
-use crate::DELIMITER;
-use crate::wtcsv::core::compatibility::WTCSVError;
+use crate::{CRLF, DELIMITER, RECORD_SEP};
+use crate::wtcsv::core::error::WTCSVError;
 use crate::wtcsv::header::Header;
 use crate::wtcsv::record::Record;
 
@@ -14,6 +14,7 @@ pub struct WTCSV {
 	pub name: String,
 	pub header: Header,
 	pub records: Vec<Record>,
+	pub crlf: bool,
 }
 
 impl WTCSV {
@@ -25,6 +26,8 @@ impl WTCSV {
 	/// Creates a record from a supported file
 	#[must_use]
 	pub fn new_from_file(file: String, name: &str) -> Result<Self, Box<dyn Error>> {
+		let crlf = file.contains(CRLF);
+
 		let header = Header::from_file(&file)?;
 
 		let mut records: Vec<String> = Vec::new();
@@ -32,27 +35,32 @@ impl WTCSV {
 		let mut delim_count = 0; // Amount of delimiters ";" encountered since last buffer flush
 		let mut buffer = "".to_owned();
 
-		for char in file.chars() {
+		let chars = file.chars().collect::<Vec<char>>();
+
+		for i in 0..chars.len() {
+			let char = chars[i];
+
 			buffer.push(char);
 
+			if char == DELIMITER {
+				delim_count += 1;
+			}
+
 			// Subtracting one as there is always one less delimiter compared to headers
-			if delim_count == header.len - 1 && char == '\n' { // End of record is indicated by \n as CLRF terminates with that
+			if delim_count == header.len - 1 && (char == RECORD_SEP) { // End of record is indicated by \n as CLRF terminates with that
 				// Cropping away the last two chars as they are CLRF - \r\n chars
-				let new_buffer = buffer.clone()[..buffer.len() - 2].to_owned();
+				let new_buffer = buffer.clone()[..buffer.len() - if crlf {2 } else {1}].to_owned();
 				records.push(new_buffer);
 				buffer.clear();
 				delim_count = 0;
 			}
-
-			if char == ';' {
-				delim_count += 1;
-			}
 		}
 
 		let mut wtcsv = Self {
 			name: name.to_string(),
 			header,
 			records: Vec::new(),
+			crlf,
 		};
 
 
@@ -98,8 +106,12 @@ impl WTCSV {
 				.collect::<Vec<String>>()
 				.join(&DELIMITER.to_string());
 
-			// Appending CLRF
-			str_record.push_str("\r\n");
+			// Appending proper line-feed
+			str_record.push_str(&if self.crlf {
+				CRLF.to_string()
+			} else {
+				RECORD_SEP.to_string()
+			});
 
 			file.push_str(&str_record);
 		}
